# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['airflow_prometheus',
 'airflow_prometheus.grafana_data',
 'airflow_prometheus.metrics',
 'airflow_prometheus.stat']

package_data = \
{'': ['*'], 'airflow_prometheus': ['templates/prometheus/*']}

install_requires = \
['Flask-Admin>=1.5.8,<2.0.0',
 'apache-airflow>=2.1.0,<3.0.0',
 'pandas>=1.3.4,<2.0.0',
 'prometheus-client>=0.10.1,<0.11.0',
 'simplekv>=0.14.1,<0.15.0',
 'typer>=0.3.2,<0.4.0',
 'wtforms>=2.3.3,<3.0.0']

entry_points = \
{'airflow.plugins': ['airflow_prometheus_plugin = '
                     'airflow_prometheus.prometheus_exporter:AirflowPrometheusPlugin'],
 'console_scripts': ['publish = publish:publish']}

setup_kwargs = {
    'name': 'airflow-prometheus',
    'version': '0.4.2',
    'description': 'Modern Prometheus exporter for Airflow (based on robinhood/airflow-prometheus-exporter)',
    'long_description': '# Airflow Prometheus (0.4.2)\n\n[![PyPI](https://img.shields.io/pypi/v/airflow-prometheus?style=flat-square)](https://pypi.org/project/airflow-prometheus/)\n[![GitHub commit activity](https://img.shields.io/github/commit-activity/m/covid-genomics/airflow-dvc?style=flat-square)](https://github.com/covid-genomics/airflow-prometheus/commits/master)\n\n\nThis is an [Airflow](https://airflow.apache.org/) extension that adds support for generating [Prometheus metrics](https://prometheus.io/).\nPackage is extension of awesome [airflow-promtheus-exporter project](https://github.com/robinhood/airflow-prometheus-exporter) by [Robinhood](https://github.com/robinhood).\n\nWe extended the project, improved the code and added new features to enable better monitoring of your Airflow workloads. :rocket:\n\n<a href="https://covidgenomics.com/">\n<img src="https://github.com/covid-genomics/airflow-dvc/blob/master/static/cg_logo.png?raw=true" width="200px"/>\n</a>\n\n\n## Installation\n\nTo install this package please do:\n```bash\n  $ python3 -m pip install "airflow-prometheus==0.4.2"\n```\n\nOr if you are using [Poetry](https://python-poetry.org/) to run Apache Airflow:\n```bash\n  $ poetry add apache-airflow@latest\n  $ poetry add "airflow-prometheus@0.4.2"\n```\n\n## What this package provides?\n\n* Support for exporting Prometheus metrics\n* Support for exporting additional data into Grafana\n\n### Prometheus metrics\n\nMetrics are exported on the `/metrics` endpoint:\n\n| Property                         | Labels                                       | Descriptions                                                                                              |\n|----------------------------------|----------------------------------------------|-----------------------------------------------------------------------------------------------------------|\n| dag_bag_stats                    | property                                     | Statistics for the dag bag:<br>* `property=loaded_dags_count` - number of loaded DAGs<br>                   |\n| airflow_dag_status               | dag_id, owner, status                        | Shows the number of dag starts with this status                                                           |\n| airflow_dag_run_duration         | dag_id                                       | Duration of successful dag_runs in seconds                                                                |\n| airflow_dag_scheduler_delay      | dag_id                                       | Airflow DAG scheduling delay                                                                              |\n| airflow_task_status              | dag_id, task_id, operator_name, owner, state | Shows the number of task instances with particular status                                                 |\n| airflow_task_duration            | aggregation, operator_name, task_id, dag_id  | Durations of tasks in seconds by operator:<br>* `aggregation=max`<br>* `aggregation=min`<br>* `aggregation=avg` |\n| airflow_task_max_tries           | operator_name, task_id, dag_id               | Max tries for tasks                                                                                       |\n| airflow_last_dag_run             | status, task_id, dag_id                      | Tasks status for latest dag run                                                                           |\n| airflow_successful_task_duration | task_id, dag_id, execution_date              | Duration of successful tasks in seconds                                                                   |\n| airflow_task_fail_count          | dag_id, task_id                              | Count of failed tasks                                                                                     |\n| airflow_xcom_parameter           | dag_id, task_id                              | Airflow Xcom Parameter                                                                                    |\n| airflow_task_scheduler_delay     | queue                                        | Airflow Task scheduling delay                                                                             |\n| airflow_num_queued_tasks         | -                                            | Airflow Number of Queued Tasks                                                                            |\n\n\n### JSON metadata\n\nYou can use [SimpleJson](https://grafana.com/grafana/plugins/grafana-simple-json-datasource/) datasource to display states of DAGs.\nInstall the plugin with the following command or via grafana.com:\n```bash\n    $ sudo grafana-cli plugins install grafana-simple-json-datasource\n```\n\nNow let\'s create a json datasource and point it to `/metrics/json/` (trailing slash is important and you may need to check skip TLS verify in order for it to work):\n\n<img src="https://github.com/covid-genomics/airflow-prometheus/blob/master/static/screen1.png?raw=true" width="700px"/>\n\nNow add ad-hoc variable:\n\n<img src="https://github.com/covid-genomics/airflow-prometheus/blob/master/static/screen2.png?raw=true" width="700px"/>\n\nNow you can see ad-hoc filter at the top of the dashboard. You can select DAGs with that filter.\nNow we need to add some visualizations.\n\n<img src="https://github.com/covid-genomics/airflow-prometheus/blob/master/static/screen3.png?raw=true" width="700px"/>\n\nWe add new panel and select newly created json datasource. As metric we select `dags` and for visualization type: `NodeGraph`\n\n\n<img src="https://github.com/covid-genomics/airflow-prometheus/blob/master/static/screen4.png?raw=true" width="700px"/>\n\nNode graph will show the dependencies between tasks and their status for the latests instance of the DAG.\nDAGs can be selected with the ad-hoc variable you created.\nYou can remove that ad-hoc filter to show all DAGs, but it\'s not recommended as NodeGraph panel is fairly bad at zooming or paning the diagram.\n\n## Example dashboard\n\nThe example dashboard is available here: [example/dashboard.json](https://raw.githubusercontent.com/covid-genomics/airflow-prometheus/master/example/dashboard.json?token=ABX26OE233IFRWRSRRWMKM3AV7UIC)\n\n<img src="https://github.com/covid-genomics/airflow-prometheus/blob/master/static/screen5.png?raw=true" width="700px"/>\n',
    'author': 'Piotr Styczyński',
    'author_email': 'piotrsty1@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
